"use strict";
var path_1 = require("path");
/**
 * Defines a command which runs on the whole webdriver server - not against a particular session
 *
 * @param {string} method The method which the command uses (e.g. `'GET'`)
 * @param {string} path The path for the command.  Uses express URL notation, so you can use
 *   /element/:elementId/command to put the parameter `elementId` in the path
 * @param {function} exec The code server-side to actually execute the command.  Receives a list
 *   of all sessions and an object containing all the url + json parameters.  The returned value
 *   will be returned to the client, and can be a promise.
 */
var GlobalCommand = (function () {
    function GlobalCommand(method, path, exec) {
        this.method = method;
        this.path = path;
        this.exec = exec;
    }
    return GlobalCommand;
}());
exports.GlobalCommand = GlobalCommand;
;
/**
 * Defines a command whcih runs against a particular session.
 *
 * @param {string} method The method which the command uses (e.g. `'GET'`)
 * @param {string} path The path for the command.  Automatically has `/session/:sessionId` prepended
 *   to it.
 * @param {function} exec The code server-side to actually execute the command.  Receives the
 *   session indicated by `sessionId` and an object containing all the paramters.  If no such
 *   session can be found, throws an error indicating such.
 */
var Command = (function () {
    function Command(method, path, exec) {
        this.method = method;
        this.path = path;
        this.exec = exec;
    }
    // Internal method
    Command.prototype._globalize = function () {
        var _this = this;
        return new GlobalCommand(this.method, path_1.posix.join('/session/:sessionId', this.path), function (sessions, params) {
            for (var _i = 0, sessions_1 = sessions; _i < sessions_1.length; _i++) {
                var session = sessions_1[_i];
                if (session.id == params['sessionId']) {
                    return _this.exec(session, params);
                }
            }
            throw { status: 6, message: 'No such session "' + params['sessionId'] + '"' };
        });
    };
    return Command;
}());
exports.Command = Command;
//# sourceMappingURL=command.js.map