"use strict";
var webdriver = require("selenium-webdriver");
var seleniumUtils = require('selenium-webdriver/http/util');
var portfinder = require('portfinder');
var lib_1 = require("../lib");
var getUrl = new lib_1.Command('GET', 'url', function (session, params) {
    return session.url;
});
var setUrl = new lib_1.Command('POST', 'url', function (session, params) {
    session.url = params['url'];
});
describe('custom commands', function () {
    var port;
    var server;
    beforeAll(function (done) {
        portfinder.getPort(function (err, p) {
            port = p;
            server = new lib_1.Server(port, function (basicSession) {
                var fullSession = basicSession;
                fullSession.url = '';
                return fullSession;
            });
            server.addCommand(getUrl);
            server.addCommand(setUrl);
            server.start();
            done();
        });
    });
    afterAll(function () {
        try {
            server.stop();
        }
        catch (e) { }
    });
    it('should be able to create and close a session', function (done) {
        var driver = new webdriver.Builder().
            usingServer('http://localhost:' + port + '/wd/hub').
            withCapabilities({ browserName: 'chrome' }).build();
        driver.getSession().then(function (session) {
            return driver.quit();
        }).then(function () {
            done();
        });
    });
    it('should be able to use custom commands', function (done) {
        var driver = new webdriver.Builder().
            usingServer('http://localhost:' + port + '/wd/hub').
            withCapabilities({ browserName: 'chrome' }).build();
        driver.getCurrentUrl().then(function (url) {
            expect(url).toBe('');
            return driver.get('http://www.google.com');
        }).then(function () {
            return driver.getCurrentUrl();
        }).then(function (url) {
            expect(url).toBe('http://www.google.com');
            done();
        });
    });
});
//# sourceMappingURL=custom_command_spec.js.map