"use strict";
var DefaultCommands = require("../lib/default-commands");
describe('default commands (unit tests)', function () {
    var chromeCaps = { browserName: 'chrome' };
    var ffCaps = { browserName: 'firefox' };
    var safariCaps = { browserName: 'safari' };
    describe('getStatus', function () {
        it('should return a status', function () {
            var result = DefaultCommands.getStatus.exec([], {});
            expect('build' in result);
            expect('os' in result);
        });
    });
    describe('newSession', function () {
        it('should add a session and return capabilities', function () {
            var sessions = [];
            var result = DefaultCommands.newSession.exec(sessions, {
                desiredCapabilities: chromeCaps
            });
            expect(sessions.length).toBe(1);
            expect(sessions[0].capabilities).toBe(result);
        });
    });
    describe('getSessions', function () {
        it('should return the sessions', function () {
            var sessions = [];
            var result = DefaultCommands.getSessions.exec(sessions, {});
            expect(result).toBe(sessions);
        });
    });
    describe('getSession', function () {
        it('should return a session\' capabilities', function () {
            var result = DefaultCommands.getSession.exec({
                id: 'id',
                capabilities: chromeCaps
            }, {});
            expect(result).toBe(chromeCaps);
        });
        it('should find the correct session from a list', function () {
            var result = DefaultCommands.getSession._globalize().exec([{
                    id: 'c',
                    capabilities: chromeCaps
                }, {
                    id: 'f',
                    capabilities: ffCaps
                }], { sessionId: 'f' });
            expect(result).toBe(ffCaps);
        });
        it('should error if it can\'t find the correct session', function (done) {
            try {
                DefaultCommands.getSession._globalize().exec([], { sessionId: 's' });
                done.fail('Invalid ID didn\'t throw an error');
            }
            catch (e) {
                expect(e.status).toBe(6);
                done();
            }
        });
    });
    describe('deleteSession', function () {
        it('should remove a session', function () {
            var sessions = [{
                    id: 'c',
                    capabilities: chromeCaps
                }, {
                    id: 'f',
                    capabilities: ffCaps
                }, {
                    id: 's',
                    capabilities: safariCaps
                }];
            DefaultCommands.deleteSession.exec(sessions, { sessionId: 'f' });
            expect(sessions.length).toBe(2);
            expect(sessions[0].id).toBe('c');
            expect(sessions[1].id).toBe('s');
        });
        it('should error if it can\'t find the correct session', function (done) {
            try {
                DefaultCommands.deleteSession.exec([], { sessionId: 'id' });
                done.fail('Invalid ID didn\'t throw an error');
            }
            catch (e) {
                expect(e.status).toBe(6);
                done();
            }
        });
    });
});
//# sourceMappingURL=default_commands_unit_spec.js.map