"use strict";
var webdriver = require("selenium-webdriver");
var seleniumUtils = require('selenium-webdriver/http/util');
var portfinder = require('portfinder');
var lib_1 = require("../lib");
describe('smoke', function () {
    var port;
    var server;
    beforeAll(function (done) {
        portfinder.getPort(function (err, p) {
            port = p;
            server = new lib_1.Server(port);
            server.start();
            done();
        });
    });
    afterAll(function () {
        try {
            server.stop();
        }
        catch (e) { }
    });
    it('should be able to create and close a session', function (done) {
        expect(server.sessions.length).toBe(0);
        var driver = new webdriver.Builder().
            usingServer('http://localhost:' + port + '/wd/hub').
            withCapabilities({ browserName: 'chrome' }).build();
        driver.getSession().then(function (session) {
            expect(server.sessions.length).toBe(1);
            expect(server.sessions[0].id).toBe(session.getId());
            return driver.quit();
        }).then(function () {
            expect(server.sessions.length).toBe(0);
            done();
        });
    });
    it('should be able to get the status', function (done) {
        seleniumUtils.getStatus('http://localhost:' + port + '/wd/hub').then(function (status) {
            expect('build' in status).toBe(true);
            expect('os' in status).toBe(true);
            done();
        });
    });
});
//# sourceMappingURL=smoke_spec.js.map